==> empire-4.2.21.tar.gz: empire-4.2.21/src/lib/subs/cnumb.c <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2005, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See the "LEGAL", "LICENSE", "CREDITS" and "README" files for all the
 *  related information and legal notices. It is expected that any future
 *  projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  cnumb.c: Return country number give country name
 * 
 *  Known contributors to this file:
 *     
 */

#include "misc.h"
#include "player.h"
#include "nat.h"
#include "file.h"
#include "prototypes.h"

int
cnumb(s_char *cntry)
{
    register s_char *ncp;
    register s_char *cp;
    register struct natstr *natp;
    int bcount;
    natid best;
    natid cn;

    bcount = 0;
    for (cn = 0; cn < MAXNOC; cn++) {
	if ((natp = getnatp(cn)) == 0)
	    break;
	ncp = natp->nat_cnam;
	for (cp = cntry; *cp == *ncp; cp++, ncp++) {
	    if (*cp == 0)
		return cn;
	}
	if (cp > cntry && *cp == 0) {
	    best = cn;
	    bcount++;
	}
    }
    /* can only have 1 match or not successful */
    return bcount == 1 ? (int)best : -1;
}

==> empire-4.3.8.tar.gz: empire-4.3.8/src/lib/subs/cnumb.c <==
/*
 *  Empire - A multi-player, client/server Internet based war game.
 *  Copyright (C) 1986-2006, Dave Pare, Jeff Bailey, Thomas Ruschak,
 *                           Ken Stevens, Steve McClure
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  ---
 *
 *  See files README, COPYING and CREDITS in the root of the source
 *  tree for related information and legal notices.  It is expected
 *  that future projects/authors will amend these files as needed.
 *
 *  ---
 *
 *  cnumb.c: Return country number give country name
 * 
 *  Known contributors to this file:
 *     
 */

#include <config.h>

#include "file.h"
#include "match.h"
#include "nat.h"
#include "prototypes.h"

/*
 * Search for a country matching CNTRY, return its number.
 * Return M_NOTFOUND if no such country exists, M_NOTUNIQUE if there
 * are several.
 */
int
cnumb(char *cntry)
{
    char *ncp;
    char *cp;
    struct natstr *natp;
    int res;
    natid cn;

    res = M_NOTFOUND;
    for (cn = 0; cn < MAXNOC; cn++) {
	if ((natp = getnatp(cn)) == 0)
	    break;
	if (natp->nat_stat == STAT_UNUSED)
	    continue;
	ncp = natp->nat_cnam;
	for (cp = cntry; *cp == *ncp; cp++, ncp++) {
	    if (*cp == 0)
		return cn;	/* exact match */
	}
	if (*cp == 0) {
	    /* is a prefix */
	    if (res >= 0)
		return M_NOTUNIQUE;
	    res = cn;
	}
    }
    return res;
}
